//
//  Endpoint.swift
//  LNPopupUIExample
//
//  Created by Vamsi Madduluri on 19/12/23.
//

import Foundation

enum Endpoint {
    case sermonsList
}

extension Endpoint {
    enum MethodType: Equatable {
        case GET
        case POST(data: Data?)
        case UPLOAD
        case PATCH(data: Data?)
        case DELETE
    }
}

extension Endpoint {
    var host: String {
        return "dev1-directus.ihdxht.easypanel.host"
    }
    var path: String {
        switch self {
        case .sermonsList:
            return "/items/sermons"
        }
    }
    var methodType: MethodType {
        switch self {
        case .sermonsList:
            return .GET
        }
    }
    var queryItems: [String: String]? {
        switch self {
        case .sermonsList:
            return ["filter[type][_eq]=":"AUDIO", "sort[]" : "-date_updated"]
        default:
            return nil
        }
    }
}

extension Endpoint {
    var url: URL? {
        var urlComponents = URLComponents()
        urlComponents.scheme = "https"
        urlComponents.host = host
        urlComponents.path = path
        var requestQueryItems = [URLQueryItem]()
        queryItems?.forEach { item in
            requestQueryItems.append(URLQueryItem(name: item.key, value: item.value))
        }
        urlComponents.queryItems = requestQueryItems
        return urlComponents.url
    }
}
