//
//  HomeViewModel.swift
//  LNPopupUIExample
//
//  Created by Vamsi Madduluri on 20/12/23.
//

import Foundation

enum ViewState {
    case loading
    case fetching
    case finished
    case noMoreData
}

@MainActor
final class HomeViewModel: ObservableObject {
    @Published var errorMessage: String?
    @Published var isMediaLoading = true
    private let networkingManager: NetworkingManagerImpl!
    @Published private(set) var error: NetworkingManager.NetworkingError?
    @Published private(set) var audoSermonsData: [AudioSermonData] = []
    @Published var hasError = false
    @Published private(set) var viewState: ViewState?
    
    init(networkingManager: NetworkingManagerImpl = NetworkingManager.shared) {
        self.networkingManager = networkingManager
    }
    
    @MainActor
    public func handleError(_ error: Error) {
        print("Full error details: \(error)")
        self.hasError = true
        if let networkingError = error as? NetworkingManager.NetworkingError {
            self.error = networkingError
            self.errorMessage = networkingError.localizedDescription
            print("Networking error details: \(networkingError)")
        }
        self.viewState = .finished
    }
    
    func fetchAudioSermons() async {
        viewState = .loading
        defer { isMediaLoading = false }
        await NetworkFetcher.shared.fetchData(
            using: networkingManager,
            endpoint: .sermonsList,
            resetAction: { self.reset() },
            updateState: { (response: AudioSermonListResponse) in
                self.audoSermonsData = response.data
                self.viewState = .finished
            },
            handleError: { error in self.handleError(error) }
        )
    }
    
    func reset() {
        self.hasError = false
        self.error = nil
        self.errorMessage = nil
    }
}
