//
//  MediaSermons.swift
//  LNPopupUIExample
//
//  Created by Vamsi Madduluri on 20/12/23.
//

import Foundation
import SwiftUI
import SDWebImageSwiftUI

struct MediaSermons: View {
    @ObservedObject var vm = HomeViewModel()
    @EnvironmentObject var audioViewModel: MusicPlayerViewModel
    var body: some View {
            VStack {
                if vm.audoSermonsData.first != nil {
                    ScrollView(.horizontal, showsIndicators: false) {
                        LazyVStack(spacing: 10) {
                            ForEach(vm.audoSermonsData, id: \.id) { sermon in
                                SermonAudioItem(sermon: sermon, vm: vm, width: 180, height: 180, audioViewModel: audioViewModel)
                            }
                        }.padding(.leading)
                    }
                }
            
        }.task {
            await vm.fetchAudioSermons()
        }
    }
}


struct SermonAudioItem: View {
    var sermon: AudioSermonData
    var vm: HomeViewModel
    var width: CGFloat? = nil
    var height: CGFloat? = nil
    @ObservedObject var audioViewModel: MusicPlayerViewModel
    var preacherName: String {
        if let name = sermon.preacherName {
            return name
        } else {
            return "Unknown"
        }
    }
    var body: some View {
        Button(action: {
            if let url = sermon.streamUrl, let audioURL = URL(string: url) {
                audioViewModel.imgUrl = "https://dev1-directus.ihdxht.easypanel.host/assets/\(sermon.artwork)"
                audioViewModel.sermonsData = sermon
                audioViewModel.setupPlayer(with: audioURL)
            }
        }, label: {
            VStack(spacing: 4) {
                WebImage(url: URL(string: "https://dev1-directus.ihdxht.easypanel.host/assets/\(sermon.artwork)"))
                    .resizable()
                    .aspectRatio(contentMode: .fill)
                    .frame(width: width, height: height)
                    .cornerRadius(8).padding(.bottom, 4)
            }
        })
    }
}
